@@ -26,13 +26,13 @@ sub _validate {
     my $self    = shift;
     my $options = $self->{_options};
     die "host should be a string"
-        if !is_string( $options->{host} );
+        if !defined $options->{host} || !is_string( $options->{host} );
     die "port should be an integer"
-        if $options->{port}
-            && !is_integer( $options->{port} );
+        if !defined $options->{port}
+            || !is_integer( $options->{port} );
 
     die "timeout should be an integer"
-        if $options->{timeout}
+        if defined $options->{timeout}
             && !is_integer( $options->{timeout} );
 
     if ( $options->{auth_type} && none { $options->{auth_type} eq $_ } @supported_auth_type ) {
@@ -64,7 +64,7 @@ __END__
 
 =head1 NAME
 
-ArangoDB::ConnectOptions;
+ArangoDB::ConnectOptions - Connect option of ArangoDB 
 
 =head1 DESCRIPTION
 
@@ -93,6 +93,16 @@ Default: 8529
 
 Seconds of HTTP connection timeout.
 
+=item keep_alive
+
+If it is true, use HTTP Keep-Alive connection.
+Default: false
+
+=item auth_type
+
+Authentication method.
+Supporting "Basic" only.
+
 =item auth_user
 
 User name for authentication
@@ -101,31 +111,30 @@ User name for authentication
 
 Password for authentication
 
-=item auth_type
-
-Authentication method.
-Supporting "Basic" only.
-
-=item keep_alive
-
-If it is true, use HTTP Keep-Alive connection.
-Default: false
-
 =item proxy
 
-HTTP proxy.
+Proxy url for HTTP connection.
 
 =back
 
+=head2 host()
+
+=head2 port()
+
+=head2 timeout()
+
+=head2 keep_alive()
+
+=head2 auth_type()
+
+=head2 auth_user()
+
+=head2 auth_passwd()
+
+=head2 proxy()
+
 =head1 AUTHOR
 
 Hideaki Ohno E<lt>hide.o.j55 {at} gmail.comE<gt>
 
-=head1 SEE ALSO
-
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =cut
