@@ -71,16 +71,3 @@ use constant {
 
 1;
 __END__
-
-=pod
-
-=head1 NAME
-
-ArangoDB::Constants;
-
-=head1 DESCRIPTION
-
-Constants of ArangoDB.
-
-=cut
-
