@@ -4,11 +4,6 @@ use warnings;
 use parent 'ArangoDB::Index';
 use Class::Accessor::Lite ( ro => [qw/fields geoJson constraint/], );
 
-sub new {
-    my $class = shift;
-    return $class->SUPER::new(@_);
-}
-
 1;
 __END__
 
@@ -16,7 +11,7 @@ __END__
 
 =head1 NAME
 
-ArangoDB::Index::Geo;
+ArangoDB::Index::Geo - An ArangoDB Geo Index
 
 =head1 DESCRIPTION
 
@@ -30,11 +25,19 @@ Constructor.
 
 =head2 id()
 
-Identifier of index.
+Returns identifier of index.
 
 =head2 type()
 
-Index type.
+Returns type of index.
+
+=head2 collection_id()
+
+Returns identifier of the index.
+
+=head2 drop()
+
+Drop the index.
 
 =head2 fields()
 
@@ -44,8 +47,12 @@ List of attribure paths.
 
 If it is true, This geo-spatial index is using geojson format.
 
-=haed2 constraint()
+=head2 constraint()
 
 If it is true, this index is geo-spatial constraint.
 
+=head1 AUTHOR
+
+Hideaki Ohno E<lt>hide.o.j55 {at} gmail.comE<gt>
+
 =cut
