@@ -4,11 +4,6 @@ use warnings;
 use parent 'ArangoDB::Index';
 use Class::Accessor::Lite ( ro => [qw/fields unique/], );
 
-sub new {
-    my $class = shift;
-    return $class->SUPER::new(@_);
-}
-
 1;
 __END__
 
@@ -16,7 +11,7 @@ __END__
 
 =head1 NAME
 
-ArangoDB::Index::Hash
+ArangoDB::Index::Hash - An ArangoDB Hash Index
 
 =head1 DESCRIPTION
 
@@ -30,11 +25,19 @@ Constructor.
 
 =head2 id()
 
-Identifier of index.
+Returns identifier of index.
 
 =head2 type()
 
-Index type.
+Returns type of index.
+
+=head2 collection_id()
+
+Returns identifier of the index.
+
+=head2 drop()
+
+Drop the index.
 
 =head2 fields()
 
@@ -44,4 +47,8 @@ List of attribute paths.
 
 If it is true, it is a unique index.
 
+=head1 AUTHOR
+
+Hideaki Ohno E<lt>hide.o.j55 {at} gmail.comE<gt>
+
 =cut
