@@ -1,19 +1,16 @@
 package ArangoDB::Statement;
 use strict;
 use warnings;
-use overload
-    q{""} => sub { $_[0]->{query} },
-    '&{}' => sub {
-    my ( $self, $options ) = @_;
-    return sub { $self->execute($options) }
-    },
-    fallback => 1;
 use Carp qw(croak);
 use JSON ();
 use ArangoDB::Cursor;
 use ArangoDB::BindVars;
 use ArangoDB::Constants qw(:api);
 
+use overload
+    q{""}    => sub { $_[0]->{query} },
+    fallback => 1;
+
 sub new {
     my ( $class, $conn, $query ) = @_;
     my $self = bless {
@@ -110,7 +107,7 @@ __END__
 
 =head1 NAME
 
-ArangoDB::Statement
+ArangoDB::Statement - ArangoDB AQL handler
 
 =head1 SYNOPSIS
 
@@ -121,17 +118,18 @@ ArangoDB::Statement
         port => 8529,
     });
   
-    my $sth = $db->query('FOR u IN users FILTER u.active == true');
+    my $sth = $db->query('FOR u IN users FILTER u.active == true RETURN u');
     my $cur = $sth->execute();
     while( my $doc = $cur->next() ){
         # do something
     }
   
     # Use bind variable
-    $sth = $db->query('FOR u IN users FILTER u.age >= @age');
-    $sth->bind( age => 18 );
-    $cur = $sth->execute();
-    while( my $doc = $cur->next() ){
+    $cur2 = $db->query(
+        'FOR u IN users FILTER u.age >= @age SORT u.name ASC RETURN u'
+    )->bind( age => 18 )->execute({ do_count => 1, batch_size => 10 });
+    
+    while( my $doc = $cur2->next() ){
         # do something
     }    
 
@@ -146,8 +144,17 @@ A AQL(Arango Query Language) statement handler.
 
 Constructor.
 
-$conn is instance of ArangoDB::Connection.
-$query is AQL statement.
+=over 4
+
+=item $conn 
+
+Instance of ArangoDB::Connection.
+
+=item $query 
+
+AQL statement.
+
+=back
 
 =head2 execute($options)
 
@@ -170,26 +177,54 @@ Boolean flag that indicates whether the number of documents found should be retu
 =head2 parse()
 
 Parse a query string without executing.
+
 Return ARRAY reference of bind variable names.
 
 =head2 explain()
 
 Get execution plan of query.
+
 Returns ARRAY reference.
 
 =head2 bind_vars($name)
 
 Returns bind variable based on $name.
+
 If $name does not passed, returns all bind variables as HASH reference.
 
 =head2 bind($vars)
-=head2 bind($key => $val)
+
+=head2 bind($key => $value)
 
 Set bind variable(s).
-$vars is HASH reference that set of key/value pairs.
 
-=head2 validate_query()
+=over 4
 
-Validate a query string without executing
+=item $vars 
+
+HASH reference that set of key/value pairs.
+
+=item $key 
+
+Bind variable name.
+
+=item $value 
+
+Bind variable value.
+
+=back
+
+Returns instance of L<ArangoDB::Statement>.You can use method chain:
+
+    my $cursor = $db->query(
+        'FOR u IN users FILTER u.type == @type && u.age >= @age SORT u.name ASC RETURN u'
+    )->bind({
+        type => 1, 
+        age  => 19 
+    })->execute();
+
+=head1 AUTHOR
+
+Hideaki Ohno E<lt>hide.o.j55 {at} gmail.comE<gt>
 
 =cut
